@@ -56,8 +56,9 @@ def get(resource, **kwargs):
     if r.status_code == 401:
         raise UnauthenticatedError()
     if r.status_code < 200 or r.status_code > 299:
-        log.exception('HTTP status code %s.  Keyword args: %s',
-                      r.status_code, kwargs)
+        if log.getEffectiveLevel() <= logging.DEBUG:
+            log.exception('HTTP GET status code %s.  Keyword args: %s',
+                          r.status_code, kwargs)
         raise JSONAPIError('Unexpected HTTP status code.', r.status_code)
     try:
         reply = r.json()
@@ -65,10 +66,39 @@ def get(resource, **kwargs):
         raise JSONAPIError('Invalid JSON data.', e)
     return reply
 
+def put(resource, json_data, **kwargs):
+    '''Issue PUT request with JSON_DATA as body to RESOURCE and return
+    parsed JSON reply or None if the request failed or returned
+    invalid JSON data.  Additional keyword arguments are passed on to
+    requests.post().
+
+    '''
+    headers = kwargs.get('headers', {})
+    headers['Content-Type'] = 'application/json'
+    kwargs['headers'] = headers
+    try:
+        r = requests.put(resource, data=json.dumps(json_data), **kwargs)
+    except requests.exceptions.RequestException as e:
+        raise JSONAPIError('requests.put exception.', e)
+    if r.status_code == 401:
+        raise UnauthenticatedError()
+    if not 200 <= r.status_code <= 299:
+        if log.getEffectiveLevel() <= logging.DEBUG:
+            log.exception('HTTP PUT status code %s.  '
+                          'Resource %s, Data: %s, keyword args: %s',
+                          r.status_code, resource, json_data, kwargs)
+        raise JSONAPIError('Unexpected HTTP status code.', r.status_code)
+    try:
+        reply = r.json()
+    except ValueError:
+        raise JSONAPIError('Invalid JSON data.', e)
+    return reply
+
 def post(resource, json_data, **kwargs):
-    '''Issue POST request for RESOURCE and return parsed JSON reply or
-    None if the request failed or returned invalid JSON data.
-    Additional keyword arguments are passed on to requests.post().
+    '''Issue POST request with JSON_DATA as body to RESOURCE and return
+    parsed JSON reply or None if the request failed or returned
+    invalid JSON data.  Additional keyword arguments are passed on to
+    requests.post().
 
     '''
     headers = kwargs.get('headers', {})
@@ -81,12 +111,36 @@ def post(resource, json_data, **kwargs):
     if r.status_code == 401:
         raise UnauthenticatedError()
     if not 200 <= r.status_code <= 299:
-        log.exception('HTTP status code %s.  '
-                      'Resource %s, Data: %s, keyword args: %s',
-                      r.status_code, resource, json_data, kwargs)
+        if log.getEffectiveLevel() <= logging.DEBUG:
+            log.exception('HTTP POST status code %s.  '
+                          'Resource %s, Data: %s, keyword args: %s',
+                          r.status_code, resource, json_data, kwargs)
         raise JSONAPIError('Unexpected HTTP status code.', r.status_code)
     try:
         reply = r.json()
     except ValueError:
         raise JSONAPIError('Invalid JSON data.', e)
     return reply
+
+def delete(resource, **kwargs):
+    '''Issue DELETE request for RESOURCE and return the parsed JSON data
+    or None if the request failed or returned invalid JSON data.
+    Additional keyword arguments are passed on to requests.delete().
+
+    '''
+    try:
+        r = requests.delete(resource, **kwargs)
+    except requests.exceptions.RequestException as e:
+        raise JSONAPIError('requests.delete exception.', e)
+    if r.status_code == 401:
+        raise UnauthenticatedError()
+    if r.status_code < 200 or r.status_code > 299:
+        if log.getEffectiveLevel() <= logging.DEBUG:
+            log.exception('HTTP DELETE status code %s.  Keyword args: %s',
+                          r.status_code, kwargs)
+            raise JSONAPIError('Unexpected HTTP status code.', r.status_code)
+    try:
+        reply = r.json()
+    except ValueError as e:
+        raise JSONAPIError('Invalid JSON data.', e)
+    return reply
